@@ -1,50 +1,34 @@
+from ttask.todotxtio import *
 import curses
-import todotxtio
 import os
 from os.path import expanduser
 
 home = expanduser("~")
 todotxt = home+'/todo.txt'
 
-def write(task: todotxtio.Todo):
+def write(task: Todo):
     global todotxt
-    todotxtio.to_file(todotxt, tasks)
+    to_file(todotxt, tasks)
 
-def switch_priority(task: todotxtio.Todo):
-    prioritys = [None, 'A', 'B', 'C']
+def switch_priority(task: Todo):
+    prioritys = ['A', 'B', 'C', 'D', 'Z']
     i = prioritys.index(task.priority)
     if i < len(prioritys) -1: i += 1
     else: i = 0
     task.priority = prioritys[i]
-    sort_tasks()
     
-def done(task: todotxtio.Todo):
-    task.completed = True
-    sort_tasks()
+def done(task: Todo):
+    task.completed ^= True
 
 def sort_tasks():
     global tasks
-    finished = []
-    unfinished = []
-    for task in tasks:
-        if task.completed:
-            finished.append(task)
-        else:
-            unfinished.append(task)
-    unfinished_p = []
-    for task in unfinished:
-        if task.priority == 'A':
-            unfinished_p.append(task)
-    for task in unfinished:
-        if task.priority == 'B':
-            unfinished_p.append(task)
-    for task in unfinished:
-        if task.priority == 'C':
-            unfinished_p.append(task)
-    for task in unfinished:
-        if task.priority == None:
-            unfinished_p.append(task)
-    tasks = unfinished_p + finished
+    tasks.sort(key=lambda x: x.priority, reverse=False)
+    f = []
+    uf = []
+    for t in tasks:
+        if t.completed: f.append(t)
+        else: uf.append(t)
+    tasks = uf + f
 
 def get_input(win: 'curses._CursesWindow', prompt: str):
     curses.echo()
@@ -84,7 +68,7 @@ def c_main(stdscr: 'curses._CursesWindow'):
         
         for index, task in enumerate(tasks):
             win1.insstr(
-                index+1, 1, f"({'-' if task.priority == None else task.priority}) [{ 'x' if task.completed else ' '}] {task.text}")
+                index+1, 1, f"({'-' if task.priority == 'Z' else task.priority}) [{ 'x' if task.completed else ' '}] {task.text}")
 
         # HIGHLIGHT SELECTED TASK
         win1.chgat(task_index+1, 1, curses.A_STANDOUT)
@@ -97,12 +81,12 @@ def c_main(stdscr: 'curses._CursesWindow'):
         ###### HANDLE KEYS
         key = stdscr.getch()
         if key == ord('a'):
-            text = get_input(win2, 'ADD: Enter task name = ')
+            text = get_input(win2, 'ADD: Enter task name =')
             if text != '':
-                newtask = todotxtio.Todo(
-                    text=text,
-                    completed=False,
-                    priority = None, 
+                newtask = Todo(
+                    text = text,
+                    completed = False,
+                    priority = 'Z', 
                 )
                 tasks.append(newtask)
             sort_tasks()
@@ -115,8 +99,10 @@ def c_main(stdscr: 'curses._CursesWindow'):
             done(selected_task)
         elif key == ord('r'): # REMOVE TASK
             if selected_task:
-                del tasks[task_index]
-                task_index -= 1
+                text = get_input(win2, 'Confirm (Y,n) =')
+                if text.lower() == 'y' or text == '':
+                    del tasks[task_index]
+                    task_index -= 1
         elif key == ord('w'): # WRITE CHANGE TO FILE
             write(tasks)
         elif key == ord('e'): # EDIT PRIORITY
@@ -129,7 +115,7 @@ def main():
     global tasks
     if not os.path.exists(todotxt):
         open(todotxt, 'w').close()
-    tasks = todotxtio.from_file(todotxt)
+    tasks = from_file(todotxt)
     sort_tasks()
     return curses.wrapper(c_main)
 
